(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([[8],{c4Bj:function(o,n,e){n=o.exports=e("JPst")(false);n.push([o.i,".cm-s-ambiance.CodeMirror {\n  -webkit-box-shadow: none;\n  -moz-box-shadow: none;\n  box-shadow: none;\n}\n",""])},i55c:function(o,n,e){var s=e("c4Bj");s=s.__esModule?s.default:s;if(typeof s==="string"){s=[[o.i,s,""]]}var a={};a.insert="head";a.singleton=false;var i=e("LboF")(s,a);if(s.locals){o.exports=s.locals}}}]);